@@ -45,6 +45,9 @@ from nemo_library.features.nemo_persistence_api import (
     getRules,
     getSubProcesses,
     getTiles,
+    createVariances,
+    deleteVariances,
+    getVariances,
 )
 from nemo_library.features.nemo_persistence_api import createProjects
 from nemo_library.features.nemo_report_api import (
@@ -67,6 +70,7 @@ from nemo_library.model.report import Report
 from nemo_library.model.rule import Rule
 from nemo_library.model.subprocess import SubProcess
 from nemo_library.model.tile import Tile
+from nemo_library.model.variance import Variance
 from nemo_library.utils.config import Config
 from nemo_library.features.deficiency_mining import createOrUpdateRulesByConfigFile
 from nemo_library.features.fileingestion import (
@@ -121,14 +125,18 @@ class NemoLibrary:
         tenant: str = None,
         userid: str = None,
         password: str = None,
-        hubspot_api_token: str = None,
         migman_local_project_directory: str = None,
         migman_proALPHA_project_status_file: str = None,
         migman_projects: list[str] = None,
         migman_mapping_fields: list[str] = None,
         migman_additional_fields: dict[str, list[str]] = None,
         migman_multi_projects: dict[str, list[str]] = None,
-        metadata: str = None,
+        metadata_directory: str = None,
+        etl_directory: str = None,
+        hubspot_api_token: str = None,
+        gedys_user_id: str = None,
+        gedys_password: str = None,
+        foxreader_statistics_file: str | None = None,
     ):
         """
         Initializes the NemoLibrary instance with configuration settings.
@@ -155,14 +163,18 @@ class NemoLibrary:
             tenant=tenant,
             userid=userid,
             password=password,
-            hubspot_api_token=hubspot_api_token,
             migman_local_project_directory=migman_local_project_directory,
             migman_proALPHA_project_status_file=migman_proALPHA_project_status_file,
             migman_projects=migman_projects,
             migman_mapping_fields=migman_mapping_fields,
             migman_additional_fields=migman_additional_fields,
             migman_multi_projects=migman_multi_projects,
-            metadata=metadata,
+            metadata_directory=metadata_directory,
+            etl_directory=etl_directory,
+            hubspot_api_token=hubspot_api_token,
+            gedys_user_id=gedys_user_id,
+            gedys_password=gedys_password,
+            foxreader_statistics_file=foxreader_statistics_file,
         )
 
         super().__init__()
@@ -962,6 +974,32 @@ class NemoLibrary:
             filter_value=filter_value,
         )
 
+    def getVariances(
+        self,
+        projectname: str,
+        filter: str = "*",
+        filter_type: FilterType = FilterType.STARTSWITH,
+        filter_value: FilterValue = FilterValue.DISPLAYNAME,
+    ) -> list[Variance]:
+        """Fetches Variances metadata with the given filters."""
+        return getVariances(
+            config=self.config,
+            projectname=projectname,
+            filter=filter,
+            filter_type=filter_type,
+            filter_value=filter_value,
+        )
+
+    def createVariances(self, projectname: str, variances: list[Variance]) -> None:
+        """Creates or updates a list of Variances."""
+        createVariances(
+            config=self.config, projectname=projectname, variances=variances
+        )
+
+    def deleteVariances(self, variances: list[str]) -> None:
+        """Deletes a list of Variances by their IDs."""
+        deleteVariances(config=self.config, variances=variances)
+
     def createRules(self, projectname: str, rules: list[Rule]) -> None:
         """Creates or updates a list of Rules."""
         createRules(config=self.config, projectname=projectname, rules=rules)
