@@ -147,6 +147,9 @@ def ReUploadFile(
         elif ext in [".fox"]:
             foxfile = FOXFile(filename)
             try:
+                if config.get_foxreader_statistics_file():
+                    pass
+                
                 df = foxfile.read()
                 meta = FOXMeta(foxfile)
                 meta.reconcile_metadata(config=config, projectname=projectname)
