@@ -19,6 +19,7 @@ from nemo_library.features.nemo_persistence_api import (
     createRules,
     createSubProcesses,
     createTiles,
+    createVariances,
     deleteApplications,
     deleteAttributeGroups,
     deleteAttributeLinks,
@@ -30,6 +31,7 @@ from nemo_library.features.nemo_persistence_api import (
     deleteRules,
     deleteSubprocesses,
     deleteTiles,
+    deleteVariances,
     getApplications,
     getAttributeGroups,
     getAttributeLinks,
@@ -40,6 +42,7 @@ from nemo_library.features.nemo_persistence_api import (
     getRules,
     getSubProcesses,
     getTiles,
+    getVariances,
 )
 from nemo_library.features.nemo_persistence_api import (
     getDependencyTree,
@@ -59,11 +62,19 @@ from nemo_library.model.report import Report
 from nemo_library.model.rule import Rule
 from nemo_library.model.tile import Tile
 from nemo_library.model.subprocess import SubProcess
+from nemo_library.model.variance import Variance
 from nemo_library.utils.config import Config
 from nemo_library.utils.utils import FilterType, FilterValue
 import uuid
 
-__all__ = ["MetaDataLoad", "MetaDataDelete", "MetaDataCreate"]
+__all__ = [
+    "MetaDataLoad",
+    "MetaDataDelete",
+    "MetaDataCreate",
+    "MetaDataHelperUpdateLinkTexts",
+    "MetaDataHelperCleanParentAttributeGroupInternalNames",
+    "MetaDataHelperAutoResolveApplications",
+]
 
 T = TypeVar("T")
 
@@ -88,6 +99,7 @@ def MetaDataLoad(
         "rules": getRules,
         "tiles": getTiles,
         "subprocesses": getSubProcesses,
+        "variances": getVariances,
     }
 
     for name, func in functions.items():
@@ -123,6 +135,7 @@ def MetaDataDelete(
         "rules": getRules,
         "subprocesses": getSubProcesses,
         "tiles": getTiles,
+        "variances": getVariances,
     }
 
     delete_functions = {
@@ -137,6 +150,7 @@ def MetaDataDelete(
         "attributegroups": deleteAttributeGroups,
         "reports": deleteReports,
         "rules": deleteRules,
+        "variances": deleteVariances,
     }
 
     for name, func in get_functions.items():
@@ -192,7 +206,9 @@ def MetaDataCreate(
 ) -> None:
 
     # load data from model (JSON)
-    logging.info(f"load model from JSON files in folder {config.get_metadata()}")
+    logging.info(
+        f"load model from JSON files in folder {config.get_metadata_directory()}"
+    )
     applications_model = _load_data_from_json(
         config,
         "applications",
@@ -292,6 +308,14 @@ def MetaDataCreate(
         filter_type=filter_type,
         filter_value=filter_value,
     )
+    variances_model = _load_data_from_json(
+        config,
+        "variances",
+        Variance,
+        filter=filter,
+        filter_type=filter_type,
+        filter_value=filter_value,
+    )
 
     # sort attribute groups
     hierarchy, _ = _attribute_groups_build_hierarchy(attributegroups_model)
@@ -387,6 +411,14 @@ def MetaDataCreate(
         filter_type=filter_type,
         filter_value=filter_value,
     )
+    variances_nemo = _fetch_data_from_nemo(
+        config=config,
+        projectname=projectname,
+        func=getVariances,
+        filter=filter,
+        filter_type=filter_type,
+        filter_value=filter_value,
+    )
 
     # reconcile data
     deletions: dict[str, list[T]] = {}
@@ -406,6 +438,7 @@ def MetaDataCreate(
         ("tiles", tiles_model, tiles_nemo),
         ("rules", rules_model, rules_nemo),
         ("subprocesses", subprocesses_model, subprocesses_nemo),
+        ("variances", variances_model, variances_nemo),
     ]:
         nemo_list_cleaned = copy.deepcopy(nemo_list)
         nemo_list_cleaned = _clean_fields(nemo_list_cleaned)
@@ -428,6 +461,7 @@ def MetaDataCreate(
         "rules": deleteRules,
         "reports": deleteReports,
         "subprocesses": deleteSubprocesses,
+        "variances": deleteVariances,
     }
 
     for key, delete_function in delete_functions.items():
@@ -449,6 +483,7 @@ def MetaDataCreate(
         "pages": createPages,
         "applications": createApplications,
         "subprocesses": createSubProcesses,
+        "variances": createVariances,
     }
 
     for key, create_function in create_functions.items():
@@ -525,7 +560,9 @@ def MetaDataHelperAutoResolveApplications(
     ASSUMPTION: model and NEMO are in sync (no deletions or updates)
     """
 
-    logging.info(f"load model from JSON files in folder {config.get_metadata()}")
+    logging.info(
+        f"load model from JSON files in folder {config.get_metadata_directory()}"
+    )
     attributegroups_model = _load_data_from_json(
         config,
         "attributegroups",
@@ -863,7 +900,7 @@ def _fetch_data_from_nemo(
 
 
 def _load_data_from_json(
-    config,
+    config : Config,
     file: str,
     cls: Type[T],
     filter: str = "*",
@@ -874,7 +911,7 @@ def _load_data_from_json(
     Loads JSON data from a file and converts it into a list of DataClass instances,
     handling nested structures recursively.
     """
-    path = Path(config.get_metadata()) / f"{file}.json"
+    path = Path(config.get_metadata_directory()) / f"{file}.json"
     if not path.exists():
         return []
 
@@ -944,8 +981,13 @@ def _find_new_objects(model_list: list[T], nemo_list: list[T]) -> list[T]:
 
 def _export_data_to_json(config: Config, file: str, data):
     data = _clean_fields(data)
-    path = Path(config.get_metadata()) / f"{file}.json"
     if data:
+
+        path = Path(config.get_metadata_directory()) / f"{file}.json"
+        
+        # Create the output directory if it does not exist
+        path.parent.mkdir(parents=True, exist_ok=True)
+        
         with open(path, "w", encoding="utf-8") as file:
             json.dump(
                 [element.to_dict() for element in data],
