@@ -29,6 +29,7 @@ from nemo_library.model.rule import Rule
 from nemo_library.utils.config import Config
 from nemo_library.features.fileingestion import ReUploadDataFrame
 from nemo_library.utils.migmanutils import (
+    DATA_CLASSIFICATIONS,
     get_mig_man_field,
     get_migman_fields,
     get_migman_mandatory_fields,
@@ -283,6 +284,12 @@ def _load_data(
                     tablefmt="plain",
                     maxcolwidths=[35, 30],
                 )
+                data_classification = DATA_CLASSIFICATIONS.get(
+                    col_migman.nemo_import_name, None
+                )
+                if data_classification:
+                    description += f"\n\nData Classification: {data_classification}"
+
                 new_columns.append(
                     Column(
                         displayName=col_migman.nemo_display_name,
@@ -292,6 +299,7 @@ def _load_data(
                         dataType="string",
                         order=f"{(columns_migman.index(col) + 1):03}",
                         columnType="ExportedColumn",
+                        dataClassificationInternalName=data_classification,
                     )
                 )
 
@@ -497,33 +505,39 @@ def _check_and_mark_duplicates(
             columnType="ExportedColumn",
         )
     )
-    new_columns.append(Column(
-        displayName="Fuzzy Match Score",
-        importName="fuzzy_match_score",
-        internalName="fuzzy_match_score",
-        description="The score of the best match for the duplicate check",
-        dataType="float",
-        order="997",
-        columnType="ExportedColumn",
-    ))
-    new_columns.append(Column(
-        displayName="Is Potential Duplicate",
-        importName="is_potential_duplicate",
-        internalName="is_potential_duplicate",
-        description="Indicates if the row is a potential duplicate based on fuzzy matching",
-        dataType="boolean",
-        order="996",
-        columnType="ExportedColumn",
-    ))
-    new_columns.append(Column(
-        displayName="Duplicate Group Key",
-        importName="duplicate_group_key",
-        internalName="duplicate_group_key",
-        description="A key that groups potential duplicates together",
-        dataType="string",
-        order="995",
-        columnType="ExportedColumn",
-    ))
+    new_columns.append(
+        Column(
+            displayName="Fuzzy Match Score",
+            importName="fuzzy_match_score",
+            internalName="fuzzy_match_score",
+            description="The score of the best match for the duplicate check",
+            dataType="float",
+            order="997",
+            columnType="ExportedColumn",
+        )
+    )
+    new_columns.append(
+        Column(
+            displayName="Is Potential Duplicate",
+            importName="is_potential_duplicate",
+            internalName="is_potential_duplicate",
+            description="Indicates if the row is a potential duplicate based on fuzzy matching",
+            dataType="boolean",
+            order="996",
+            columnType="ExportedColumn",
+        )
+    )
+    new_columns.append(
+        Column(
+            displayName="Duplicate Group Key",
+            importName="duplicate_group_key",
+            internalName="duplicate_group_key",
+            description="A key that groups potential duplicates together",
+            dataType="string",
+            order="995",
+            columnType="ExportedColumn",
+        )
+    )
     return datadf_cleaned
 
 
