@@ -19,6 +19,7 @@ from nemo_library.model.report import Report
 from nemo_library.model.rule import Rule
 from nemo_library.model.subprocess import SubProcess
 from nemo_library.model.tile import Tile
+from nemo_library.model.variance import Variance
 from nemo_library.utils.config import Config
 from nemo_library.utils.utils import FilterType, FilterValue, log_error
 
@@ -439,6 +440,26 @@ def getRules(
     )
 
 
+def getVariances(
+    config: Config,
+    projectname: str,
+    filter: str = "*",
+    filter_type: FilterType = FilterType.STARTSWITH,
+    filter_value: FilterValue = FilterValue.DISPLAYNAME,
+) -> list[Variance]:
+    """Fetches Variances metadata with the given filters."""
+    return _generic_metadata_get(
+        config,
+        projectname,
+        "Variance",
+        "/variances",
+        Variance,
+        filter,
+        filter_type,
+        filter_value,
+    )
+
+
 def deleteColumns(config: Config, columns: list[str]) -> None:
     """Deletes a list of Columns by their IDs."""
     _generic_metadata_delete(config, columns, "Columns")
@@ -494,6 +515,11 @@ def deleteRules(config: Config, rules: list[str]) -> None:
     _generic_metadata_delete(config, rules, "Rule")
 
 
+def deleteVariances(config: Config, variances: list[str]) -> None:
+    """Deletes a list of Variances by their IDs."""
+    _generic_metadata_delete(config, variances, "Variance")
+
+
 def createColumns(config: Config, projectname: str, columns: list[Column]) -> None:
     """Creates or updates a list of columns."""
     _generic_metadata_create_or_update(
@@ -624,6 +650,19 @@ def createRules(config: Config, projectname: str, rules: list[Rule]) -> None:
     )
 
 
+def createVariances(
+    config: Config, projectname: str, variances: list[Variance]
+) -> None:
+    """Creates or updates a list of Variances."""
+    _generic_metadata_create_or_update(
+        config=config,
+        projectname=projectname,
+        objects=variances,
+        endpoint="Variance",
+        get_existing_func=getVariances,
+    )
+
+
 def getProjects(
     config: Config,
     filter: str = "*",
