@@ -1,20 +1,20 @@
 from dataclasses import asdict, dataclass
-from typing import List, Dict
-from datetime import datetime
 from uuid import UUID
 
+
 @dataclass
 class SubProcess:
     """
-    Represents a subprocess with various attributes including names, descriptions, 
+    Represents a subprocess with various attributes including names, descriptions,
     translations, aggregations, and identifiers.
     """
-    columnInternalNames: List[str]
+
+    columnInternalNames: list[str]
     description: str
-    descriptionTranslations: Dict[str, str]
+    descriptionTranslations: dict[str, str]
     displayName: str
-    displayNameTranslations: Dict[str, str]
-    groupByAggregations: Dict[str, str]
+    displayNameTranslations: dict[str, str]
+    groupByAggregations: dict[str, str]
     groupByColumn: str
     internalName: str
     isAggregation: bool
@@ -22,6 +22,8 @@ class SubProcess:
     id: str
     projectId: UUID
     tenant: str
+    isCustom: bool = False
+    metadataClassificationInternalName: str = ""
 
     def to_dict(self):
         """
@@ -30,4 +32,4 @@ class SubProcess:
         Returns:
             dict: A dictionary representation of the SubProcess instance.
         """
-        return asdict(self)
\ No newline at end of file
+        return asdict(self)
