@@ -51,18 +51,22 @@ class Config:
     def __init__(
         self,
         config_file: str = "config.ini",
-        environment: str = None,
-        tenant: str = None,
-        userid: str = None,
-        password: str = None,
-        hubspot_api_token: str = None,
-        migman_local_project_directory: str = None,
-        migman_proALPHA_project_status_file: str = None,
-        migman_projects: list[str] = None,
-        migman_mapping_fields: list[str] = None,
-        migman_additional_fields: dict[str, list[str]] = None,
-        migman_multi_projects: dict[str, list[str]] = None,
-        metadata: str = None,
+        environment: str | None = None,
+        tenant: str | None = None,
+        userid: str | None = None,
+        password: str | None = None,
+        migman_local_project_directory: str | None = None,
+        migman_proALPHA_project_status_file: str | None = None,
+        migman_projects: list[str] | None = None,
+        migman_mapping_fields: list[str] | None = None,
+        migman_additional_fields: dict[str, list[str]] | None = None,
+        migman_multi_projects: dict[str, list[str]] | None = None,
+        metadata_directory: str | None = None,
+        etl_directory: str | None = None,
+        hubspot_api_token: str | None = None,
+        gedys_user_id: str | None = None,
+        gedys_password: str | None = None,
+        foxreader_statistics_file : str | None = None,
     ):
         """
         Initializes the Config class with optional parameters or values from a configuration file.
@@ -107,9 +111,6 @@ class Config:
             "nemo_library", "environment", fallback=None
         )
         logging.info(f"Using environment: {self.environment}")
-        self.hubspot_api_token = hubspot_api_token or self.config.get(
-            "nemo_library", "hubspot_api_token", fallback=None
-        )
 
         self.migman_local_project_directory = (
             migman_local_project_directory
@@ -179,14 +180,33 @@ class Config:
         )
         logging.info(f"Using MigMan multi-projects: {self.migman_multi_projects}")
 
-        self.metadata = metadata or self.config.get(
+        self.metadata_directory = metadata_directory or self.config.get(
             "nemo_library", "metadata", fallback=None
         )
-        if self.metadata:
-            logging.info(f"Using metadata path: {Path(self.metadata).absolute()}")
+        if self.metadata_directory:
+            logging.info(f"Using metadata path: {Path(self.metadata_directory).absolute()}")
         else:
             logging.warning("No metadata path specified.")
 
+        self.etl_directory = etl_directory or self.config.get(
+            "nemo_library", "etl_directory", fallback=None
+        )
+        self.hubspot_api_token = hubspot_api_token or self.config.get(
+            "nemo_library", "hubspot_api_token", fallback=None
+        )
+        self.gedys_user_id = gedys_user_id or self.config.get(
+            "nemo_library", "gedys_user_id", fallback=None
+        )
+        logging.info(f"Using Gedys user ID: {self.gedys_user_id}")
+        self.gedys_password = gedys_password or self.config.get(
+            "nemo_library", "gedys_password", fallback=None
+        )
+
+        self.foxreader_statistics_file = foxreader_statistics_file or self.config.get(
+            "nemo_library", "foxreader_statistics_file", fallback=None
+        )
+        logging.info(f"Using fox statistics file: {self.foxreader_statistics_file}")
+
         # Initialize tokens to None to make them persistent later
         self._id_token = None
         self._access_token = None
@@ -206,7 +226,7 @@ class Config:
         try:
             return NEMO_URLS[env]
         except KeyError:
-            raise Exception(f"unknown environment '{env}' provided")
+            raise Exception(f"unknown environment '{env}' provided. Environment must be one of {list(NEMO_URLS.keys())}")
 
     def get_tenant(self) -> str:
         """
@@ -307,6 +327,33 @@ class Config:
         """
         return self.migman_multi_projects
 
+    def get_gedys_user_id(self) -> str | None:
+        """
+        Retrieves the user ID for Gedys.
+
+        Returns:
+            str: The user ID for Gedys.
+        """
+        return self.gedys_user_id
+
+    def get_gedys_password(self) -> str | None:
+        """
+        Retrieves the password for Gedys.
+
+        Returns:
+            str: The password for Gedys.
+        """
+        return self.gedys_password
+
+    def get_etl_directory(self) -> str | None:
+        """
+        Retrieves the etl_directory
+
+        Returns:
+            str: The etl_directory
+        """
+        return self.etl_directory
+
     def connection_get_headers(self) -> dict[str, str]:
         """
         Retrieves the headers for the connection.
@@ -347,7 +394,7 @@ class Config:
         try:
             return COGNITO_URLS[env]
         except KeyError:
-            raise Exception(f"unknown environment '{env}' provided")
+            raise Exception(f"unknown environment '{env}' provided. Environment must be one of {list(COGNITO_URLS.keys())}")
 
     def connection_get_cognito_appclientid(self) -> str:
         """
@@ -363,7 +410,7 @@ class Config:
         try:
             return COGNITO_APPCLIENT_IDS[env]
         except KeyError:
-            raise Exception(f"unknown environment '{env}' provided")
+            raise Exception(f"unknown environment '{env}' provided. Environment must be one of {list(COGNITO_APPCLIENT_IDS.keys())}")
 
     def connection_get_tokens(self) -> tuple[str, str, str]:
         """
@@ -409,14 +456,23 @@ class Config:
 
         return self._id_token, self._access_token, self._refresh_token
 
-    def get_metadata(self) -> str:
+    def get_metadata_directory(self) -> str | None:
         """
         Retrieves the metadata path.
 
         Returns:
             str: The metadata path.
         """
-        return self.metadata
+        return self.metadata_directory
+
+    def get_foxreader_statistics_file(self) -> str | None:
+        """
+        Retrieves the FOXReader statistics file path.
+
+        Returns:
+            str: The FOXReader statistics file path.
+        """
+        return self.foxreader_statistics_file
 
     def testLogin(self) -> None:
         """
