@@ -113,31 +113,58 @@ SYNONYM_FIELDS = {
 
 DUPLICATE_CHECK_FIELDS = {
     "Parts": [
-        "S_ArtikelSpr.Bezeichnung (002)",
-        "S_ArtikelSpr.Bezeichnung (003)",
-        "S_ArtikelSpr.Bezeichnung (004)",
-        "S_ArtikelSpr.Bezeichnung (006)",
+        "S_ArtikelSpr.Bezeichnung1",
+        "S_ArtikelSpr.Bezeichnung2",
+        "S_ArtikelSpr.Bezeichnung3",
+        "S_ArtikelSpr.Bezeichnung4",
     ],
     "Suppliers": [
-        "S_Adresse.Name1 (003)",
-        "S_Adresse.Staat (004)",
-        "S_Adresse.Ort (005)",
-        "S_Adresse.Name2 (012)",
-        "S_Adresse.Name3 (013)",
-        "S_Adresse.PLZ (014)",
-        "S_Adresse.Strasse (018)",
-        "S_Adresse.Hausnummer (020)",
+        "S_Adresse.Name1",
+        "S_Adresse.Staat",
+        "S_Adresse.Ort",
+        "S_Adresse.Name2",
+        "S_Adresse.Name3",
+        "S_Adresse.PLZ",
+        "S_Adresse.Strasse",
+        "S_Adresse.Hausnummer",
     ],
     "Customers": [
-        "S_Adresse.Name1 (003)",
-        "S_Adresse.Staat (004)",
-        "S_Adresse.Ort (005)",
-        "S_Adresse.Name2 (012)",
-        "S_Adresse.Name3 (013)",
-        "S_Adresse.PLZ (014)",
-        "S_Adresse.Strasse (018)",
-        "S_Adresse.Hausnummer (020)",
+        "S_Adresse.Name1",
+        "S_Adresse.Staat",
+        "S_Adresse.Ort",
+        "S_Adresse.Name2",
+        "S_Adresse.Name3",
+        "S_Adresse.PLZ",
+        "S_Adresse.Strasse",
+        "S_Adresse.Hausnummer",
     ],
+    "Prospects": [
+        "S_Adresse.Name1",
+        "S_Adresse.Staat",
+        "S_Adresse.Ort",
+        "S_Adresse.Name2",
+        "S_Adresse.Name3",
+        "S_Adresse.PLZ",
+        "S_Adresse.Strasse",
+        "S_Adresse.Hausnummer",
+    ],
+}
+
+DATA_CLASSIFICATIONS = {
+    "S_Adresse.HomePage": "url",
+    "S_Adresse.EMail": "email",
+    "S_Adresse.Handy": "phone_number",
+    "S_Adresse.Telefax": "phone_number",
+    "S_Adresse.Telefon": "phone_number",
+    "S_Adresse.Telefon2": "phone_number",
+    "S_Adresse.Name1": "address",
+    "S_Adresse.Name2": "address",
+    "S_Adresse.Name3": "address",
+    "S_Adresse.Staat": "address",
+    "S_Adresse.Ort": "address",
+    "S_Adresse.PLZ": "address",
+    "S_Adresse.Strasse": "address",
+    "S_Adresse.Hausnummer": "address",
 }
 
 
