@@ -13,5 +13,5 @@ def getNL():
         migman_mapping_fields=["S_Kunde.Kunde"],
         migman_additional_fields={},
         migman_multi_projects={},
-        metadata="metadata_optimate",
+        metadata_directory="metadata_optimate",
     )
